@@ -76,12 +76,12 @@ def when(expression):
         @wraps(method)
         def wrapped(self):
             if predicate(self.current_state):
-                self.log.info('Invoking: %s', id)
+                self.log.debug('Invoking: %s', id)
                 method(self)
             else:
                 self.log.debug('Skipping: %s', id)
         StateAwareMixin.conditions[predicate] = wrapped
-        return wrapped
+        return method
     return wrapper
 
 
@@ -100,8 +100,8 @@ def toggle(expression):
         @wraps(method)
         def wrapped(self):
             condition = predicate(self.current_state)
-            self.log.info('Invoking: %s(%s)', id, condition)
+            self.log.debug('Invoking: %s(%s)', id, condition)
             method(self, condition)
         StateAwareMixin.conditions[predicate] = wrapped
-        return wrapped
+        return method
     return wrapper
